==> com.liferay.dynamic.data.mapping.form.builder-2.0.15.jar: META-INF/resources/js/components/Form/FormRenderer.es.js <==
"use strict";

Liferay.Loader.define("dynamic-data-mapping-form-builder@2.0.15/js/components/Form/FormRenderer.es", ['module', 'exports', 'require', '../Page/PageRenderer.es', '../SuccessPage/SuccessPage.es', 'frontend-taglib-clay$clay-button', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', './FormRenderer.soy', 'frontend-js-metal-web$metal-state', '../../util/config.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = void 0;

  require("../Page/PageRenderer.es");

  require("../SuccessPage/SuccessPage.es");

  require("frontend-taglib-clay$clay-button");

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _FormRendererSoy = _interopRequireDefault(require("./FormRenderer.soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  var _config = require("../../util/config.es");

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  /**
   * FormRenderer.
   * @extends Component
   */
  var FormRenderer =
  /*#__PURE__*/
  function (_Component) {
    _inherits(FormRenderer, _Component);

    function FormRenderer() {
      _classCallCheck(this, FormRenderer);

      return _possibleConstructorReturn(this, _getPrototypeOf(FormRenderer).apply(this, arguments));
    }

    _createClass(FormRenderer, [{
      key: "_handleFieldBlurred",
      value: function _handleFieldBlurred(event) {
        this.emit('fieldBlurred', event);
      }
    }, {
      key: "_handleFieldClicked",
      value: function _handleFieldClicked(index) {
        this.emit('fieldClicked', index);
      }
    }, {
      key: "_handleFieldEdited",
      value: function _handleFieldEdited(event) {
        this.emit('fieldEdited', event);
      }
    }, {
      key: "_handlePaginationItemClicked",
      value: function _handlePaginationItemClicked(_ref) {
        var dataset = _ref.delegateTarget.dataset;
        var dispatch = this.context.dispatch;
        var pageIndex = dataset.pageIndex;
        dispatch('activePageUpdated', Number(pageIndex));
      }
    }, {
      key: "_handlePaginationLeftClicked",
      value: function _handlePaginationLeftClicked() {
        var activePage = this.activePage;
        var index = activePage - 1;

        if (activePage == -1) {
          index = this.pages.length - 1;
        }

        this.emit('activePageUpdated', index);
      }
    }, {
      key: "_handlePaginationRightClicked",
      value: function _handlePaginationRightClicked() {
        var activePage = this.activePage;
        var index = activePage + 1;

        if (index == this.pages.length) {
          index = -1;
        }

        this.emit('activePageUpdated', index);
      }
    }]);

    return FormRenderer;
  }(_metalComponent.default);

  _defineProperty(FormRenderer, "STATE", {
    /**
     * @default
     * @instance
     * @memberof FormRenderer
     * @type {?number}
     */
    activePage: _metalState.Config.number().value(0),

    /**
     * @default false
     * @instance
     * @memberof FormRenderer
     * @type {?bool}
     */
    editable: _metalState.Config.bool().value(false),

    /**
     * @default []
     * @instance
     * @memberof FormRenderer
     * @type {?array<object>}
     */
    pages: _metalState.Config.arrayOf(_config.pageStructure).value([]),

    /**
     * @default undefined
     * @instance
     * @memberof FormRenderer
     * @type {!string}
     */
    spritemap: _metalState.Config.string().required()
  });

  _metalSoy.default.register(FormRenderer, _FormRendererSoy.default);

  var _default = FormRenderer;
  exports.default = _default;
  //# sourceMappingURL=FormRenderer.es.js.map
});
//# sourceMappingURL=FormRenderer.es.js.map

==> com.liferay.dynamic.data.mapping.form.builder-2.0.17.jar: META-INF/resources/js/components/Form/FormRenderer.es.js <==
"use strict";

Liferay.Loader.define("dynamic-data-mapping-form-builder@2.0.17/js/components/Form/FormRenderer.es", ['module', 'exports', 'require', '../Page/PageRenderer.es', '../SuccessPage/SuccessPage.es', 'frontend-taglib-clay$clay-button', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', './FormRenderer.soy', 'frontend-js-metal-web$metal-state', '../../util/config.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = void 0;

  require("../Page/PageRenderer.es");

  require("../SuccessPage/SuccessPage.es");

  require("frontend-taglib-clay$clay-button");

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _FormRendererSoy = _interopRequireDefault(require("./FormRenderer.soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  var _config = require("../../util/config.es");

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * FormRenderer.
   * @extends Component
   */
  var FormRenderer =
  /*#__PURE__*/
  function (_Component) {
    _inherits(FormRenderer, _Component);

    function FormRenderer() {
      _classCallCheck(this, FormRenderer);

      return _possibleConstructorReturn(this, _getPrototypeOf(FormRenderer).apply(this, arguments));
    }

    _createClass(FormRenderer, [{
      key: "_handleFieldBlurred",
      value: function _handleFieldBlurred(event) {
        this.emit('fieldBlurred', event);
      }
    }, {
      key: "_handleFieldClicked",
      value: function _handleFieldClicked(index) {
        this.emit('fieldClicked', index);
      }
    }, {
      key: "_handleFieldEdited",
      value: function _handleFieldEdited(event) {
        this.emit('fieldEdited', event);
      }
    }, {
      key: "_handlePaginationItemClicked",
      value: function _handlePaginationItemClicked(_ref) {
        var dataset = _ref.delegateTarget.dataset;
        var dispatch = this.context.dispatch;
        var pageIndex = dataset.pageIndex;
        dispatch('activePageUpdated', Number(pageIndex));
      }
    }, {
      key: "_handlePaginationLeftClicked",
      value: function _handlePaginationLeftClicked() {
        var activePage = this.activePage;
        var index = activePage - 1;

        if (activePage == -1) {
          index = this.pages.length - 1;
        }

        this.emit('activePageUpdated', index);
      }
    }, {
      key: "_handlePaginationRightClicked",
      value: function _handlePaginationRightClicked() {
        var activePage = this.activePage;
        var index = activePage + 1;

        if (index == this.pages.length) {
          index = -1;
        }

        this.emit('activePageUpdated', index);
      }
    }]);

    return FormRenderer;
  }(_metalComponent.default);

  FormRenderer.STATE = {
    /**
     * @default
     * @instance
     * @memberof FormRenderer
     * @type {?number}
     */
    activePage: _metalState.Config.number().value(0),

    /**
     * @default false
     * @instance
     * @memberof FormRenderer
     * @type {?bool}
     */
    editable: _metalState.Config.bool().value(false),

    /**
     * @default []
     * @instance
     * @memberof FormRenderer
     * @type {?array<object>}
     */
    pages: _metalState.Config.arrayOf(_config.pageStructure).value([]),

    /**
     * @default undefined
     * @instance
     * @memberof FormRenderer
     * @type {!string}
     */
    spritemap: _metalState.Config.string().required()
  };

  _metalSoy.default.register(FormRenderer, _FormRendererSoy.default);

  var _default = FormRenderer;
  exports.default = _default;
  //# sourceMappingURL=FormRenderer.es.js.map
});
//# sourceMappingURL=FormRenderer.es.js.map
